@@ -1,13 +1,25 @@
 <?php
+/**
+ * WordPress Administration Bootstrap
+ *
+ * @package WordPress
+ * @subpackage Administration
+ */
+
+/**
+ * In WordPress Administration Panels
+ *
+ * @since unknown
+ */
 define('WP_ADMIN', TRUE);
 
 if ( defined('ABSPATH') )
-	require_once( ABSPATH . 'wp-config.php');
+	require_once(ABSPATH . 'wp-load.php');
 else
-    require_once('../wp-config.php');
+	require_once('../wp-load.php');
 
 if ( get_option('db_version') != $wp_db_version ) {
-	wp_redirect(get_option('siteurl') . '/wp-admin/upgrade.php?_wp_http_referer=' . urlencode(stripslashes($_SERVER['REQUEST_URI'])));
+	wp_redirect(admin_url('upgrade.php?_wp_http_referer=' . urlencode(stripslashes($_SERVER['REQUEST_URI']))));
 	exit;
 }
 
@@ -26,8 +38,8 @@ $time_format = get_option('time_format');
 
 wp_reset_vars(array('profile', 'redirect', 'redirect_url', 'a', 'popuptitle', 'popupurl', 'text', 'trackback', 'pingback'));
 
-wp_admin_css_color('classic', __('Classic'), get_option( 'siteurl' ) . "/wp-admin/css/colors-classic.css", array('#07273E', '#14568A', '#D54E21', '#2683AE'));
-wp_admin_css_color('fresh', __('Fresh'), get_option( 'siteurl' ) . "/wp-admin/css/colors-fresh.css", array('#464646', '#CEE1EF', '#D54E21', '#2683AE'));
+wp_admin_css_color('classic', __('Blue'), admin_url("css/colors-classic.css"), array('#073447', '#21759B', '#EAF3FA', '#BBD8E7'));
+wp_admin_css_color('fresh', __('Gray'), admin_url("css/colors-fresh.css"), array('#464646', '#6D6D6D', '#F1F1F1', '#DFDFDF'));
 
 wp_enqueue_script( 'common' );
 wp_enqueue_script( 'jquery-color' );
@@ -45,7 +57,19 @@ do_action('admin_init');
 
 // Handle plugin admin pages.
 if (isset($plugin_page)) {
-	$page_hook = get_plugin_page_hook($plugin_page, $pagenow);
+	if( ! $page_hook = get_plugin_page_hook($plugin_page, $pagenow) ) {
+		$page_hook = get_plugin_page_hook($plugin_page, $plugin_page);
+		// backwards compatibility for plugins using add_management_page
+		if ( empty( $page_hook ) && 'edit.php' == $pagenow && '' != get_plugin_page_hook($plugin_page, 'tools.php') ) {
+			// There could be plugin specific params on the URL, so we need the whole query string
+			if ( !empty($_SERVER[ 'QUERY_STRING' ]) )
+				$query_string = $_SERVER[ 'QUERY_STRING' ];
+			else
+				$query_string = 'page=' . $plugin_page;
+			wp_redirect( 'tools.php?' . $query_string );
+			exit;
+		}
+	}
 
 	if ( $page_hook ) {
 		do_action('load-' . $page_hook);
@@ -58,7 +82,7 @@ if (isset($plugin_page)) {
 			wp_die(__('Invalid plugin page'));
 		}
 
-		if (! ( file_exists(ABSPATH . PLUGINDIR . "/$plugin_page") && is_file( ABSPATH . PLUGINDIR . "/$plugin_page") ) )
+		if (! ( file_exists(WP_PLUGIN_DIR . "/$plugin_page") && is_file(WP_PLUGIN_DIR . "/$plugin_page") ) )
 			wp_die(sprintf(__('Cannot load %s.'), htmlentities($plugin_page)));
 
 		do_action('load-' . $plugin_page);
@@ -66,7 +90,7 @@ if (isset($plugin_page)) {
 		if (! isset($_GET['noheader']))
 			require_once(ABSPATH . 'wp-admin/admin-header.php');
 
-		include(ABSPATH . PLUGINDIR . "/$plugin_page");
+		include(WP_PLUGIN_DIR . "/$plugin_page");
 	}
 
 	include(ABSPATH . 'wp-admin/admin-footer.php');
@@ -84,7 +108,7 @@ if (isset($plugin_page)) {
 	}
 
 	// Allow plugins to define importers as well
-	if (! is_callable($wp_importers[$importer][2]))
+	if ( !isset($wp_importers) || !isset($wp_importers[$importer]) || ! is_callable($wp_importers[$importer][2]))
 	{
 		if (! file_exists(ABSPATH . "wp-admin/import/$importer.php"))
 		{
@@ -93,7 +117,7 @@ if (isset($plugin_page)) {
 		include(ABSPATH . "wp-admin/import/$importer.php");
 	}
 
-	$parent_file = 'edit.php';
+	$parent_file = 'tools.php';
 	$submenu_file = 'import.php';
 	$title = __('Import');
 
@@ -108,9 +132,16 @@ if (isset($plugin_page)) {
 
 	include(ABSPATH . 'wp-admin/admin-footer.php');
 
+	// Make sure rules are flushed
+	global $wp_rewrite;
+	$wp_rewrite->flush_rules();
+
 	exit();
 } else {
 	do_action("load-$pagenow");
 }
 
+if ( !empty($_REQUEST['action']) )
+	do_action('admin_action_' . $_REQUEST['action']);
+
 ?>
