@@ -1,5 +1,21 @@
 <?php
+/**
+ * WordPress Comment Administration API.
+ *
+ * @package WordPress
+ * @subpackage Administration
+ */
 
+/**
+ * {@internal Missing Short Description}}
+ *
+ * @since unknown
+ * @uses $wpdb
+ *
+ * @param string $comment_author
+ * @param string $comment_date
+ * @return mixed Comment ID on success.
+ */
 function comment_exists($comment_author, $comment_date) {
 	global $wpdb;
 
@@ -7,6 +23,11 @@ function comment_exists($comment_author, $comment_date) {
 			WHERE comment_author = %s AND comment_date = %s", $comment_author, $comment_date) );
 }
 
+/**
+ * {@internal Missing Short Description}}
+ *
+ * @since unknown
+ */
 function edit_comment() {
 
 	$comment_post_ID = (int) $_POST['comment_post_ID'];
@@ -28,7 +49,6 @@ function edit_comment() {
 		}
 	}
 
-
 	if (!empty ( $_POST['edit_date'] ) ) {
 		$aa = $_POST['aa'];
 		$mm = $_POST['mm'];
@@ -46,6 +66,14 @@ function edit_comment() {
 	wp_update_comment( $_POST);
 }
 
+/**
+ * {@internal Missing Short Description}}
+ *
+ * @since unknown
+ *
+ * @param unknown_type $id
+ * @return unknown
+ */
 function get_comment_to_edit( $id ) {
 	if ( !$comment = get_comment($id) )
 		return false;
@@ -64,6 +92,15 @@ function get_comment_to_edit( $id ) {
 	return $comment;
 }
 
+/**
+ * {@internal Missing Short Description}}
+ *
+ * @since unknown
+ * @uses $wpdb
+ *
+ * @param int $post_id Post ID
+ * @return unknown
+ */
 function get_pending_comments_num( $post_id ) {
 	global $wpdb;
 
@@ -90,8 +127,15 @@ function get_pending_comments_num( $post_id ) {
 	return $pending_keyed;
 }
 
-// Add avatars to relevant places in admin, or try to
-
+/**
+ * Add avatars to relevant places in admin, or try to.
+ *
+ * @since unknown
+ * @uses $comment
+ *
+ * @param string $name User name.
+ * @return string Avatar with Admin name.
+ */
 function floated_admin_avatar( $name ) {
 	global $comment;
 
@@ -107,6 +151,11 @@ function floated_admin_avatar( $name ) {
 	return "$avatar $name";
 }
 
+function enqueue_comment_hotkeys_js() {
+	if ( 'true' == get_user_option( 'comment_shortcuts' ) )
+		wp_enqueue_script( 'jquery-table-hotkeys' );
+}
+
 if ( is_admin() && ('edit-comments.php' == $pagenow || 'edit.php' == $pagenow) ) {
 	if ( get_option('show_avatars') )
 		add_filter( 'comment_author', 'floated_admin_avatar' );
