@@ -1,41 +1,47 @@
 <?php
+/**
+ * Link Management Administration Panel.
+ *
+ * @package WordPress
+ * @subpackage Administration
+ */
 
+/** Load WordPress Administration Bootstrap */
 require_once ('admin.php');
 
 // Handle bulk deletes
-if ( isset($_GET['deleteit']) && isset($_GET['linkcheck']) ) {
+if ( isset($_GET['action']) && isset($_GET['linkcheck']) ) {
 	check_admin_referer('bulk-bookmarks');
+	$doaction = $_GET['action'] ? $_GET['action'] : $_GET['action2'];
 
 	if ( ! current_user_can('manage_links') )
 		wp_die( __('You do not have sufficient permissions to edit the links for this blog.') );
 
-	foreach ( (array) $_GET['linkcheck'] as $link_id) {
-		$link_id = (int) $link_id;
+	if ( 'delete' == $doaction ) {
+		foreach ( (array) $_GET['linkcheck'] as $link_id ) {
+			$link_id = (int) $link_id;
 
-		wp_delete_link($link_id);
+			wp_delete_link($link_id);
+		}
+
+		wp_redirect( wp_get_referer() );
+		exit;
 	}
-
-	$sendback = wp_get_referer();
-	$sendback = preg_replace('|[^a-z0-9-~+_.?#=&;,/:]|i', '', $sendback);
-	wp_redirect($sendback);
-	exit;
-} elseif ( !empty($_GET['_wp_http_referer']) ) {
-	 wp_redirect(remove_query_arg(array('_wp_http_referer', '_wpnonce'), stripslashes($_SERVER['REQUEST_URI'])));
+} elseif ( isset($_GET['_wp_http_referer']) && ! empty($_GET['_wp_http_referer']) ) {
+	 wp_redirect( remove_query_arg( array('_wp_http_referer', '_wpnonce'), stripslashes($_SERVER['REQUEST_URI']) ) );
 	 exit;
 }
 
-wp_enqueue_script('admin-forms');
-
 wp_reset_vars(array('action', 'cat_id', 'linkurl', 'name', 'image', 'description', 'visible', 'target', 'category', 'link_id', 'submit', 'order_by', 'links_show_cat_id', 'rating', 'rel', 'notes', 'linkcheck[]'));
 
-if (empty ($cat_id))
+if ( empty($cat_id) )
 	$cat_id = 'all';
 
-if (empty ($order_by))
+if ( empty($order_by) )
 	$order_by = 'order_name';
 
-$title = __('Manage Links');
-$this_file = $parent_file = 'edit.php';
+$title = __('Edit Links');
+$this_file = $parent_file = 'link-manager.php';
 include_once ("./admin-header.php");
 
 if (!current_user_can('manage_links'))
@@ -61,10 +67,18 @@ switch ($order_by) {
 	default :
 		$sqlorderby = 'name';
 		break;
-}
+} ?>
 
+<div class="wrap nosubsub">
+<?php screen_icon(); ?>
+<h2><?php echo wp_specialchars( $title );
+if ( isset($_GET['s']) && $_GET['s'] )
+	printf( '<span class="subtitle">' . __('Search results for &#8220;%s&#8221;') . '</span>', wp_specialchars( stripslashes($_GET['s']) ) ); ?>
+</h2>
+
+<?php
 if ( isset($_GET['deleted']) ) {
-	echo '<div style="background-color: rgb(207, 235, 247);" id="message" class="updated fade"><p>';
+	echo '<div id="message" class="updated fade"><p>';
 	$deleted = (int) $_GET['deleted'];
 	printf(__ngettext('%s link deleted.', '%s links deleted', $deleted), $deleted);
 	echo '</p></div>';
@@ -72,22 +86,25 @@ if ( isset($_GET['deleted']) ) {
 }
 ?>
 
-<div class="wrap">
-
-<form id="posts-filter" action="" method="get">
-<h2><?php printf( __( 'Manage Links (<a href="%s">add new</a>)' ), 'link-add.php' ); ?></h2>
-
-<p id="post-search">
-	<input type="text" id="post-search-input" name="s" value="<?php echo attribute_escape(stripslashes($_GET['s'])); ?>" />
+<form class="search-form" action="" method="get">
+<p class="search-box">
+	<label class="hidden" for="link-search-input"><?php _e( 'Search Links' ); ?>:</label>
+	<input type="text" class="search-input" id="link-search-input" name="s" value="<?php _admin_search_query(); ?>" />
 	<input type="submit" value="<?php _e( 'Search Links' ); ?>" class="button" />
 </p>
-
+</form>
 <br class="clear" />
 
+<form id="posts-filter" action="" method="get">
 <div class="tablenav">
 
-<div class="alignleft">
-<input type="submit" value="<?php _e('Delete'); ?>" name="deleteit" class="button-secondary delete" />
+<div class="alignleft actions">
+<select name="action">
+<option value="" selected="selected"><?php _e('Bulk Actions'); ?></option>
+<option value="delete"><?php _e('Delete'); ?></option>
+</select>
+<input type="submit" value="<?php _e('Apply'); ?>" name="doaction" id="doaction" class="button-secondary action" />
+
 <?php
 $categories = get_terms('link_category', "hide_empty=1");
 $select_cat = "<select name=\"cat_id\">\n";
@@ -114,18 +131,7 @@ echo $select_order;
 <br class="clear" />
 </div>
 
-<br class="clear" />
-
-<?php
-$link_columns = array(
-	'name'       => '<th style="width: 15%;">' . __('Name') . '</th>',
-	'url'       => '<th>' . __('URL') . '</th>',
-	'categories' => '<th>' . __('Categories') . '</th>',
-	'rel'      => '<th style="text-align: center">' . __('rel') . '</th>',
-	'visible'   => '<th style="text-align: center">' . __('Visible') . '</th>',
-);
-$link_columns = apply_filters('manage_link_columns', $link_columns);
-?>
+<div class="clear"></div>
 
 <?php
 if ( 'all' == $cat_id )
@@ -135,48 +141,79 @@ if ( !empty($_GET['s']) )
 	$args['search'] = $_GET['s'];
 $links = get_bookmarks( $args );
 if ( $links ) {
+	$link_columns = get_column_headers('link-manager');
+	$hidden = get_hidden_columns('link-manager');
 ?>
 
 <?php wp_nonce_field('bulk-bookmarks') ?>
-<table class="widefat">
+<table class="widefat fixed" cellspacing="0">
 	<thead>
 	<tr>
-	<th scope="col" class="check-column"><input type="checkbox" onclick="checkAll(document.getElementById('posts-filter'));" /></th>
-<?php foreach($link_columns as $column_display_name) {
-	echo $column_display_name;
-} ?>
+<?php print_column_headers('link-manager'); ?>
 	</tr>
 	</thead>
+
+	<tfoot>
+	<tr>
+<?php print_column_headers('link-manager', false); ?>
+	</tr>
+	</tfoot>
+
 	<tbody>
 <?php
+	$alt = 0;
+
 	foreach ($links as $link) {
 		$link = sanitize_bookmark($link);
 		$link->link_name = attribute_escape($link->link_name);
 		$link->link_category = wp_get_link_cats($link->link_id);
 		$short_url = str_replace('http://', '', $link->link_url);
-		$short_url = str_replace('www.', '', $short_url);
+		$short_url = preg_replace('/^www./i', '', $short_url);
 		if ('/' == substr($short_url, -1))
 			$short_url = substr($short_url, 0, -1);
 		if (strlen($short_url) > 35)
 			$short_url = substr($short_url, 0, 32).'...';
-
 		$visible = ($link->link_visible == 'Y') ? __('Yes') : __('No');
-		++ $i;
-		$style = ($i % 2) ? '' : ' class="alternate"';
+		$style = ($alt % 2) ? '' : ' class="alternate"';
+		++ $alt;
+		$edit_link = get_edit_bookmark_link();
 		?><tr id="link-<?php echo $link->link_id; ?>" valign="middle" <?php echo $style; ?>><?php
-		echo '<th scope="row" class="check-column"><input type="checkbox" name="linkcheck[]" value="'.$link->link_id.'" /></th>';
 		foreach($link_columns as $column_name=>$column_display_name) {
+			$class = "class=\"column-$column_name\"";
+
+			$style = '';
+			if ( in_array($column_name, $hidden) )
+				$style = ' style="display:none;"';
+			if ( 'visible' == $column_name )
+				$style = empty($style) ? ' style="text-align: center;"' : ' style="text-align: center; display: none;"';
+			$attributes = "$class$style";
+
 			switch($column_name) {
+				case 'cb':
+					echo '<th scope="row" class="check-column"><input type="checkbox" name="linkcheck[]" value="'.$link->link_id.'" /></th>';
+					break;
 				case 'name':
 
-					echo "<td><strong><a class='row-title' href='link.php?link_id=$link->link_id&amp;action=edit' title='" . attribute_escape(sprintf(__('Edit "%s"'), $link->link_name)) . "' class='edit'>$link->link_name</a></strong><br />";
-					echo $link->link_description . "</td>";
+					echo "<td $attributes><strong><a class='row-title' href='$edit_link' title='" . attribute_escape(sprintf(__('Edit "%s"'), $link->link_name)) . "'>$link->link_name</a></strong><br />";
+					$actions = array();
+					$actions['edit'] = '<a href="' . $edit_link . '">' . __('Edit') . '</a>';
+					$actions['delete'] = "<a class='submitdelete' href='" . wp_nonce_url("link.php?action=delete&amp;link_id=$link->link_id", 'delete-bookmark_' . $link->link_id) . "' onclick=\"if ( confirm('" . js_escape(sprintf( __("You are about to delete this link '%s'\n  'Cancel' to stop, 'OK' to delete."), $link->link_name )) . "') ) { return true;}return false;\">" . __('Delete') . "</a>";
+					$action_count = count($actions);
+					$i = 0;
+					echo '<div class="row-actions">';
+					foreach ( $actions as $action => $linkaction ) {
+						++$i;
+						( $i == $action_count ) ? $sep = '' : $sep = ' | ';
+						echo "<span class='$action'>$linkaction$sep</span>";
+					}
+					echo '</div>';
+					echo '</td>';
 					break;
 				case 'url':
-					echo "<td><a href='$link->link_url' title='".sprintf(__('Visit %s'), $link->link_name)."'>$short_url</a></td>";
+					echo "<td $attributes><a href='$link->link_url' title='".sprintf(__('Visit %s'), $link->link_name)."'>$short_url</a></td>";
 					break;
 				case 'categories':
-					?><td><?php
+					?><td <?php echo $attributes ?>><?php
 					$cat_names = array();
 					foreach ($link->link_category as $category) {
 						$cat = get_term($category, 'link_category', OBJECT, 'display');
@@ -188,13 +225,13 @@ if ( $links ) {
 						$cat_names[] = $cat_name;
 					}
 					echo implode(', ', $cat_names);
-					?> </td><?php
+					?></td><?php
 					break;
 				case 'rel':
-					?><td><?php echo $link->link_rel; ?></td><?php
+					?><td <?php echo $attributes ?>><?php echo $link->link_rel; ?></td><?php
 					break;
 				case 'visible':
-					?><td style='text-align: center;'><?php echo $visible; ?></td><?php
+					?><td <?php echo $attributes ?>><?php echo $visible; ?></td><?php
 					break;
 				default:
 					?>
@@ -213,15 +250,40 @@ if ( $links ) {
 <?php } else { ?>
 <p><?php _e('No links found.') ?></p>
 <?php } ?>
+
+<div class="tablenav">
+
+<div class="alignleft actions">
+<select name="action2">
+<option value="" selected="selected"><?php _e('Bulk Actions'); ?></option>
+<option value="delete"><?php _e('Delete'); ?></option>
+</select>
+<input type="submit" value="<?php _e('Apply'); ?>" name="doaction2" id="doaction2" class="button-secondary action" />
+</div>
+
+<br class="clear" />
+</div>
+
 </form>
 
 <div id="ajax-response"></div>
 
-<div class="tablenav">
-<br class="clear" />
 </div>
 
-
-</div>
+<script type="text/javascript">
+/* <![CDATA[ */
+(function($){
+	$(document).ready(function(){
+		$('#doaction, #doaction2').click(function(){
+			if ( $('select[name^="action"]').val() == 'delete' ) {
+				var m = '<?php echo js_escape(__("You are about to delete the selected links.\n  'Cancel' to stop, 'OK' to delete.")); ?>';
+				return showNotice.warn(m);
+			}
+		});
+	});
+})(jQuery);
+columns.init('link-manager');
+/* ]]> */
+</script>
 
 <?php include('admin-footer.php'); ?>
