@@ -1,3 +1,9 @@
+<?php
+/**
+ * @package WordPress
+ * @subpackage Default_Theme
+ */
+?>
 
 <hr />
 <div id="footer">
