@@ -1,17 +1,34 @@
 <?php
+/**
+ * WordPress Link Template Functions
+ *
+ * @package WordPress
+ * @subpackage Template
+ */
 
-
+/**
+ * Display the permalink for the current post.
+ *
+ * @since 1.2.0
+ * @uses apply_filters() Calls 'the_permalink' filter on the permalink string.
+ */
 function the_permalink() {
 	echo apply_filters('the_permalink', get_permalink());
 }
 
-
 /**
- * Conditionally adds a trailing slash if the permalink structure
- * has a trailing slash, strips the trailing slash if not
- * @global object Uses $wp_rewrite
- * @param $string string a URL with or without a trailing slash
- * @param $type_of_url string the type of URL being considered (e.g. single, category, etc) for use in the filter
+ * Retrieve trailing slash string, if blog set for adding trailing slashes.
+ *
+ * Conditionally adds a trailing slash if the permalink structure has a trailing
+ * slash, strips the trailing slash if not. The string is passed through the
+ * 'user_trailingslashit' filter. Will remove trailing slash from string, if
+ * blog is not set to have them.
+ *
+ * @since 2.2.0
+ * @uses $wp_rewrite
+ *
+ * @param $string String a URL with or without a trailing slash.
+ * @param $type_of_url String the type of URL being considered (e.g. single, category, etc) for use in the filter.
  * @return string
  */
 function user_trailingslashit($string, $type_of_url = '') {
@@ -27,7 +44,16 @@ function user_trailingslashit($string, $type_of_url = '') {
 	return $string;
 }
 
-
+/**
+ * Display permalink anchor for current post.
+ *
+ * The permalink mode title will use the post title for the 'a' element 'id'
+ * attribute. The id mode uses 'post-' with the post ID for the 'id' attribute.
+ *
+ * @since 0.71
+ *
+ * @param string $mode Permalink mode can be either 'title', 'id', or default, which is 'id'.
+ */
 function permalink_anchor($mode = 'id') {
 	global $post;
 	switch ( strtolower($mode) ) {
@@ -42,8 +68,16 @@ function permalink_anchor($mode = 'id') {
 	}
 }
 
-
-function get_permalink($id = 0, $leavename=false) {
+/**
+ * Retrieve full permalink for current post or post ID.
+ *
+ * @since 1.0.0
+ *
+ * @param int $id Optional. Post ID.
+ * @param bool $leavename Optional, defaults to false. Whether to keep post name or page name.
+ * @return string
+ */
+function get_permalink($id = 0, $leavename = false) {
 	$rewritecode = array(
 		'%year%',
 		'%monthnum%',
@@ -58,9 +92,12 @@ function get_permalink($id = 0, $leavename=false) {
 		$leavename? '' : '%pagename%',
 	);
 
-	$post = &get_post($id);
+	if ( is_object($id) && isset($id->filter) && 'sample' == $id->filter )
+		$post = $id;
+	else
+		$post = &get_post($id);
 
-	if ( empty($post->ID) ) return FALSE;
+	if ( empty($post->ID) ) return false;
 
 	if ( $post->post_type == 'page' )
 		return get_page_link($post->ID, $leavename);
@@ -75,17 +112,17 @@ function get_permalink($id = 0, $leavename=false) {
 		$category = '';
 		if ( strpos($permalink, '%category%') !== false ) {
 			$cats = get_the_category($post->ID);
-			if ( $cats )
+			if ( $cats ) {
 				usort($cats, '_usort_terms_by_ID'); // order by ID
-			$category = $cats[0]->slug;
-			if ( $parent=$cats[0]->parent )
-				$category = get_category_parents($parent, FALSE, '/', TRUE) . $category;
-
+				$category = $cats[0]->slug;
+				if ( $parent = $cats[0]->parent )
+					$category = get_category_parents($parent, false, '/', true) . $category;
+			}
 			// show default category in permalinks, without
 			// having to assign it explicitly
 			if ( empty($category) ) {
 				$default_category = get_category( get_option( 'default_category' ) );
-				$category = is_wp_error( $default_category ) ? '' : $default_category->slug; 
+				$category = is_wp_error( $default_category ) ? '' : $default_category->slug;
 			}
 		}
 
@@ -112,19 +149,37 @@ function get_permalink($id = 0, $leavename=false) {
 		);
 		$permalink = get_option('home') . str_replace($rewritecode, $rewritereplace, $permalink);
 		$permalink = user_trailingslashit($permalink, 'single');
-		return apply_filters('post_link', $permalink, $post);
+		return apply_filters('post_link', $permalink, $post, $leavename);
 	} else { // if they're not using the fancy permalink option
 		$permalink = get_option('home') . '/?p=' . $post->ID;
-		return apply_filters('post_link', $permalink, $post);
+		return apply_filters('post_link', $permalink, $post, $leavename);
 	}
 }
 
-// get permalink from post ID
+/**
+ * Retrieve permalink from post ID.
+ *
+ * @since 1.0.0
+ *
+ * @param int $post_id Optional. Post ID.
+ * @param mixed $deprecated Not used.
+ * @return string
+ */
 function post_permalink($post_id = 0, $deprecated = '') {
 	return get_permalink($post_id);
 }
 
-// Respects page_on_front.  Use this one.
+/**
+ * Retrieve the permalink for current page or page ID.
+ *
+ * Respects page_on_front. Use this one.
+ *
+ * @since 1.5.0
+ *
+ * @param int $id Optional. Post ID.
+ * @param bool $leavename Optional, defaults to false. Whether to keep post name or page name.
+ * @return string
+ */
 function get_page_link($id = false, $leavename = false) {
 	global $post;
 
@@ -140,7 +195,18 @@ function get_page_link($id = false, $leavename = false) {
 	return apply_filters('page_link', $link, $id);
 }
 
-// Ignores page_on_front.  Internal use only.
+/**
+ * Retrieve the page permalink.
+ *
+ * Ignores page_on_front. Internal use only.
+ *
+ * @since 2.1.0
+ * @access private
+ *
+ * @param int $id Optional. Post ID.
+ * @param bool $leavename Optional. Leave name.
+ * @return string
+ */
 function _get_page_link( $id = false, $leavename = false ) {
 	global $post, $wp_rewrite;
 
@@ -163,6 +229,16 @@ function _get_page_link( $id = false, $leavename = false ) {
 	return apply_filters( '_get_page_link', $link, $id );
 }
 
+/**
+ * Retrieve permalink for attachment.
+ *
+ * This can be used in the WordPress Loop or outside of it.
+ *
+ * @since 2.0.0
+ *
+ * @param int $id Optional. Post ID.
+ * @return string
+ */
 function get_attachment_link($id = false) {
 	global $post, $wp_rewrite;
 
@@ -194,6 +270,14 @@ function get_attachment_link($id = false) {
 	return apply_filters('attachment_link', $link, $id);
 }
 
+/**
+ * Retrieve the permalink for the year archives.
+ *
+ * @since 1.5.0
+ *
+ * @param int|bool $year False for current year or year for permalink.
+ * @return string
+ */
 function get_year_link($year) {
 	global $wp_rewrite;
 	if ( !$year )
@@ -207,6 +291,15 @@ function get_year_link($year) {
 	}
 }
 
+/**
+ * Retrieve the permalink for the month archives with year.
+ *
+ * @since 1.0.0
+ *
+ * @param bool|int $year False for current year. Integer of year.
+ * @param bool|int $month False for current month. Integer of month.
+ * @return string
+ */
 function get_month_link($year, $month) {
 	global $wp_rewrite;
 	if ( !$year )
@@ -223,6 +316,16 @@ function get_month_link($year, $month) {
 	}
 }
 
+/**
+ * Retrieve the permalink for the day archives with year and month.
+ *
+ * @since 1.0.0
+ *
+ * @param bool|int $year False for current year. Integer of year.
+ * @param bool|int $month False for current month. Integer of month.
+ * @param bool|int $day False for current day. Integer of day.
+ * @return string
+ */
 function get_day_link($year, $month, $day) {
 	global $wp_rewrite;
 	if ( !$year )
@@ -243,6 +346,14 @@ function get_day_link($year, $month, $day) {
 	}
 }
 
+/**
+ * Retrieve the permalink for the feed type.
+ *
+ * @since 1.5.0
+ *
+ * @param string $feed Optional, defaults to default feed. Feed type.
+ * @return string
+ */
 function get_feed_link($feed = '') {
 	global $wp_rewrite;
 
@@ -272,6 +383,15 @@ function get_feed_link($feed = '') {
 	return apply_filters('feed_link', $output, $feed);
 }
 
+/**
+ * Retrieve the permalink for the post comments feed.
+ *
+ * @since 2.2.0
+ *
+ * @param int $post_id Optional. Post ID.
+ * @param string $feed Optional. Feed type.
+ * @return string
+ */
 function get_post_comments_feed_link($post_id = '', $feed = '') {
 	global $id;
 
@@ -297,19 +417,21 @@ function get_post_comments_feed_link($post_id = '', $feed = '') {
 	return apply_filters('post_comments_feed_link', $url);
 }
 
-/** post_comments_feed_link() - Output the comment feed link for a post.
+/**
+ * Display the comment feed link for a post.
  *
- * Prints out the comment feed link for a post.  Link text is placed in the
- * anchor.  If no link text is specified, default text is used.  If no post ID
- * is specified, the current post is used.
+ * Prints out the comment feed link for a post. Link text is placed in the
+ * anchor. If no link text is specified, default text is used. If no post ID is
+ * specified, the current post is used.
  *
  * @package WordPress
  * @subpackage Feed
- * @since 2.5
+ * @since 2.5.0
  *
- * @param string Descriptive text
- * @param int Optional post ID.  Default to current post.
- * @return string Link to the comment feed for the current post
+ * @param string $link_text Descriptive text.
+ * @param int $post_id Optional post ID.  Default to current post.
+ * @param string $feed Optional. Feed format.
+ * @return string Link to the comment feed for the current post.
 */
 function post_comments_feed_link( $link_text = '', $post_id = '', $feed = '' ) {
 	$url = get_post_comments_feed_link($post_id, $feed);
@@ -319,6 +441,20 @@ function post_comments_feed_link( $link_text = '', $post_id = '', $feed = '' ) {
 	echo "<a href='$url'>$link_text</a>";
 }
 
+/**
+ * Retrieve the feed link for a given author.
+ *
+ * Returns a link to the feed for all posts by a given author. A specific feed
+ * can be requested or left blank to get the default feed.
+ *
+ * @package WordPress
+ * @subpackage Feed
+ * @since 2.5.0
+ *
+ * @param int $author_id ID of an author.
+ * @param string $feed Optional. Feed type.
+ * @return string Link to the feed for the author specified by $author_id.
+*/
 function get_author_feed_link( $author_id, $feed = '' ) {
 	$author_id = (int) $author_id;
 	$permalink_structure = get_option('permalink_structure');
@@ -327,29 +463,35 @@ function get_author_feed_link( $author_id, $feed = '' ) {
 		$feed = get_default_feed();
 
 	if ( '' == $permalink_structure ) {
-		$link = get_option('home') . '?feed=rss2&amp;author=' . $author_id;
+		$link = get_option('home') . "?feed=$feed&amp;author=" . $author_id;
 	} else {
 		$link = get_author_posts_url($author_id);
-		$link = trailingslashit($link) . user_trailingslashit('feed', 'feed');
+		if ( $feed == get_default_feed() )
+			$feed_link = 'feed';
+		else
+			$feed_link = "feed/$feed";
+
+		$link = trailingslashit($link) . user_trailingslashit($feed_link, 'feed');
 	}
 
-	$link = apply_filters('author_feed_link', $link);
+	$link = apply_filters('author_feed_link', $link, $feed);
 
 	return $link;
 }
 
-/** get_category_feed_link() - Get the feed link for a given category
+/**
+ * Retrieve the feed link for a category.
  *
- * Returns a link to the feed for all post in a given category.  A specific feed can be requested
- * or left blank to get the default feed.
+ * Returns a link to the feed for all post in a given category. A specific feed
+ * can be requested or left blank to get the default feed.
  *
  * @package WordPress
  * @subpackage Feed
- * @since 2.5
+ * @since 2.5.0
  *
- * @param int $cat_id ID of a category
- * @param string $feed Feed type
- * @return string Link to the feed for the category specified by $cat_id
+ * @param int $cat_id ID of a category.
+ * @param string $feed Optional. Feed type.
+ * @return string Link to the feed for the category specified by $cat_id.
 */
 function get_category_feed_link($cat_id, $feed = '') {
 	$cat_id = (int) $cat_id;
@@ -381,6 +523,15 @@ function get_category_feed_link($cat_id, $feed = '') {
 	return $link;
 }
 
+/**
+ * Retrieve permalink for feed of tag.
+ *
+ * @since 2.3.0
+ *
+ * @param int $tag_id Tag ID.
+ * @param string $feed Optional. Feed type.
+ * @return string
+ */
 function get_tag_feed_link($tag_id, $feed = '') {
 	$tag_id = (int) $tag_id;
 
@@ -410,6 +561,57 @@ function get_tag_feed_link($tag_id, $feed = '') {
 	return $link;
 }
 
+/**
+ * Retrieve edit tag link.
+ *
+ * @since 2.7.0
+ *
+ * @param int $tag_id Tag ID
+ * @return string
+ */
+function get_edit_tag_link( $tag_id = 0 ) {
+	$tag = get_term($tag_id, 'post_tag');
+
+	if ( !current_user_can('manage_categories') )
+		return;
+
+	$location = admin_url('edit-tags.php?action=edit&amp;tag_ID=') . $tag->term_id;
+	return apply_filters( 'get_edit_tag_link', $location );
+}
+
+/**
+ * Display or retrieve edit tag link with formatting.
+ *
+ * @since 2.7.0
+ *
+ * @param string $link Optional. Anchor text.
+ * @param string $before Optional. Display before edit link.
+ * @param string $after Optional. Display after edit link.
+ * @param int|object $tag Tag object or ID
+ * @return string|null HTML content, if $echo is set to false.
+ */
+function edit_tag_link( $link = '', $before = '', $after = '', $tag = null ) {
+	$tag = get_term($tag, 'post_tag');
+
+	if ( !current_user_can('manage_categories') )
+		return;
+
+	if ( empty($link) )
+		$link = __('Edit This');
+
+	$link = '<a href="' . get_edit_tag_link( $tag->term_id ) . '" title="' . __( 'Edit tag' ) . '">' . $link . '</a>';
+	echo $before . apply_filters( 'edit_tag_link', $link, $tag->term_id ) . $after;
+}
+
+/**
+ * Retrieve the permalink for the feed of the search results.
+ *
+ * @since 2.5.0
+ *
+ * @param string $search_query Optional. Search query.
+ * @param string $feed Optional. Feed type.
+ * @return string
+ */
 function get_search_feed_link($search_query = '', $feed = '') {
 	if ( empty($search_query) )
 		$search = attribute_escape(get_search_query());
@@ -426,6 +628,15 @@ function get_search_feed_link($search_query = '', $feed = '') {
 	return $link;
 }
 
+/**
+ * Retrieve the permalink for the comments feed of the search results.
+ *
+ * @since 2.5.0
+ *
+ * @param string $search_query Optional. Search query.
+ * @param string $feed Optional. Feed type.
+ * @return string
+ */
 function get_search_comments_feed_link($search_query = '', $feed = '') {
 	if ( empty($search_query) )
 		$search = attribute_escape(get_search_query());
@@ -442,6 +653,18 @@ function get_search_comments_feed_link($search_query = '', $feed = '') {
 	return $link;
 }
 
+/**
+ * Retrieve edit posts link for post.
+ *
+ * Can be used within the WordPress loop or outside of it. Can be used with
+ * pages, posts, attachments, and revisions.
+ *
+ * @since 2.3.0
+ *
+ * @param int $id Optional. Post ID.
+ * @param string $context Optional, default to display. How to write the '&', defaults to '&amp;'.
+ * @return string
+ */
 function get_edit_post_link( $id = 0, $context = 'display' ) {
 	if ( !$post = &get_post( $id ) )
 		return;
@@ -478,10 +701,19 @@ function get_edit_post_link( $id = 0, $context = 'display' ) {
 		$var  = 'post';
 		break;
 	endswitch;
-	
+
 	return apply_filters( 'get_edit_post_link', admin_url("$file.php?{$action}$var=$post->ID"), $post->ID, $context );
 }
 
+/**
+ * Retrieve edit posts link for post.
+ *
+ * @since 1.0.0
+ *
+ * @param string $link Optional. Anchor text.
+ * @param string $before Optional. Display before edit link.
+ * @param string $after Optional. Display after edit link.
+ */
 function edit_post_link( $link = 'Edit This', $before = '', $after = '' ) {
 	global $post;
 
@@ -493,10 +725,18 @@ function edit_post_link( $link = 'Edit This', $before = '', $after = '' ) {
 			return;
 	}
 
-	$link = '<a href="' . get_edit_post_link( $post->ID ) . '" title="' . __( 'Edit post' ) . '">' . $link . '</a>';
+	$link = '<a class="post-edit-link" href="' . get_edit_post_link( $post->ID ) . '" title="' . attribute_escape( __( 'Edit post' ) ) . '">' . $link . '</a>';
 	echo $before . apply_filters( 'edit_post_link', $link, $post->ID ) . $after;
 }
 
+/**
+ * Retrieve edit comment link.
+ *
+ * @since 2.3.0
+ *
+ * @param int $comment_id Optional. Comment ID.
+ * @return string
+ */
 function get_edit_comment_link( $comment_id = 0 ) {
 	$comment = &get_comment( $comment_id );
 	$post = &get_post( $comment->comment_post_ID );
@@ -513,6 +753,16 @@ function get_edit_comment_link( $comment_id = 0 ) {
 	return apply_filters( 'get_edit_comment_link', $location );
 }
 
+/**
+ * Display or retrieve edit comment link with formatting.
+ *
+ * @since 1.0.0
+ *
+ * @param string $link Optional. Anchor text.
+ * @param string $before Optional. Display before edit link.
+ * @param string $after Optional. Display after edit link.
+ * @return string|null HTML content, if $echo is set to false.
+ */
 function edit_comment_link( $link = 'Edit This', $before = '', $after = '' ) {
 	global $comment, $post;
 
@@ -525,20 +775,91 @@ function edit_comment_link( $link = 'Edit This', $before = '', $after = '' ) {
 			return;
 	}
 
-	$link = '<a href="' . get_edit_comment_link( $comment->comment_ID ) . '" title="' . __( 'Edit comment' ) . '">' . $link . '</a>';
+	$link = '<a class="comment-edit-link" href="' . get_edit_comment_link( $comment->comment_ID ) . '" title="' . __( 'Edit comment' ) . '">' . $link . '</a>';
 	echo $before . apply_filters( 'edit_comment_link', $link, $comment->comment_ID ) . $after;
 }
 
+/**
+ * Display edit bookmark (literally a URL external to blog) link.
+ *
+ * @since 2.7.0
+ *
+ * @param int $link Optional. Bookmark ID.
+ * @return string
+ */
+function get_edit_bookmark_link( $link = 0 ) {
+	$link = get_bookmark( $link );
+
+	if ( !current_user_can('manage_links') )
+		return;
+
+	$location = admin_url('link.php?action=edit&amp;link_id=') . $link->link_id;
+	return apply_filters( 'get_edit_bookmark_link', $location, $link->link_id );
+}
+
+/**
+ * Display edit bookmark (literally a URL external to blog) link anchor content.
+ *
+ * @since 2.7.0
+ *
+ * @param string $link Optional. Anchor text.
+ * @param string $before Optional. Display before edit link.
+ * @param string $after Optional. Display after edit link.
+ * @param int $bookmark Optional. Bookmark ID.
+ */
+function edit_bookmark_link( $link = '', $before = '', $after = '', $bookmark = null ) {
+	$bookmark = get_bookmark($bookmark);
+
+	if ( !current_user_can('manage_links') )
+		return;
+
+	if ( empty($link) )
+		$link = __('Edit This');
+
+	$link = '<a href="' . get_edit_bookmark_link( $link ) . '" title="' . __( 'Edit link' ) . '">' . $link . '</a>';
+	echo $before . apply_filters( 'edit_bookmark_link', $link, $bookmark->link_id ) . $after;
+}
+
 // Navigation links
 
+/**
+ * Retrieve previous post link that is adjacent to current post.
+ *
+ * @since 1.5.0
+ *
+ * @param bool $in_same_cat Optional. Whether link should be in same category.
+ * @param string $excluded_categories Optional. Excluded categories IDs.
+ * @return string
+ */
 function get_previous_post($in_same_cat = false, $excluded_categories = '') {
 	return get_adjacent_post($in_same_cat, $excluded_categories);
 }
 
+/**
+ * Retrieve next post link that is adjacent to current post.
+ *
+ * @since 1.5.0
+ *
+ * @param bool $in_same_cat Optional. Whether link should be in same category.
+ * @param string $excluded_categories Optional. Excluded categories IDs.
+ * @return string
+ */
 function get_next_post($in_same_cat = false, $excluded_categories = '') {
 	return get_adjacent_post($in_same_cat, $excluded_categories, false);
 }
 
+/**
+ * Retrieve adjacent post link.
+ *
+ * Can either be next or previous post link.
+ *
+ * @since 2.5.0
+ *
+ * @param bool $in_same_cat Optional. Whether link should be in same category.
+ * @param string $excluded_categories Optional. Excluded categories IDs.
+ * @param bool $previous Optional. Whether to retrieve previous post.
+ * @return string
+ */
 function get_adjacent_post($in_same_cat = false, $excluded_categories = '', $previous = true) {
 	global $post, $wpdb;
 
@@ -554,7 +875,7 @@ function get_adjacent_post($in_same_cat = false, $excluded_categories = '', $pre
 
 		if ( $in_same_cat ) {
 			$cat_array = wp_get_object_terms($post->ID, 'category', 'fields=ids');
-			$join .= " AND tt.taxonomy = 'category' AND tt.term_id IN (" . implode($cat_array, ',') . ')';
+			$join .= " AND tt.taxonomy = 'category' AND tt.term_id IN (" . implode(',', $cat_array) . ")";
 		}
 
 		$posts_in_ex_cats_sql = "AND tt.taxonomy = 'category'";
@@ -582,14 +903,47 @@ function get_adjacent_post($in_same_cat = false, $excluded_categories = '', $pre
 	return $wpdb->get_row("SELECT p.* FROM $wpdb->posts AS p $join $where $sort");
 }
 
+/**
+ * Display previous post link that is adjacent to the current post.
+ *
+ * @since 1.5.0
+ *
+ * @param string $format Optional. Link anchor format.
+ * @param string $link Optional. Link permalink format.
+ * @param bool $in_same_cat Optional. Whether link should be in same category.
+ * @param string $excluded_categories Optional. Excluded categories IDs.
+ */
 function previous_post_link($format='&laquo; %link', $link='%title', $in_same_cat = false, $excluded_categories = '') {
 	adjacent_post_link($format, $link, $in_same_cat, $excluded_categories, true);
 }
 
+/**
+ * Display next post link that is adjacent to the current post.
+ *
+ * @since 1.5.0
+ *
+ * @param string $format Optional. Link anchor format.
+ * @param string $link Optional. Link permalink format.
+ * @param bool $in_same_cat Optional. Whether link should be in same category.
+ * @param string $excluded_categories Optional. Excluded categories IDs.
+ */
 function next_post_link($format='%link &raquo;', $link='%title', $in_same_cat = false, $excluded_categories = '') {
 	adjacent_post_link($format, $link, $in_same_cat, $excluded_categories, false);
 }
 
+/**
+ * Display adjacent post link.
+ *
+ * Can be either next post link or previous.
+ *
+ * @since 2.5.0
+ *
+ * @param string $format Link anchor format.
+ * @param string $link Link permalink format.
+ * @param bool $in_same_cat Optional. Whether link should be in same category.
+ * @param string $excluded_categories Optional. Excluded categories IDs.
+ * @param bool $previous Optional, default is true. Whether display link to previous post.
+ */
 function adjacent_post_link($format, $link, $in_same_cat = false, $excluded_categories = '', $previous = true) {
 	if ( $previous && is_attachment() )
 		$post = & get_post($GLOBALS['post']->post_parent);
@@ -605,8 +959,11 @@ function adjacent_post_link($format, $link, $in_same_cat = false, $excluded_cate
 		$title = $previous ? __('Previous Post') : __('Next Post');
 
 	$title = apply_filters('the_title', $title, $post);
+	$date = mysql2date(get_option('date_format'), $post->post_date);
+
 	$string = '<a href="'.get_permalink($post).'">';
 	$link = str_replace('%title', $title, $link);
+	$link = str_replace('%date', $date, $link);
 	$link = $string . $link . '</a>';
 
 	$format = str_replace('%link', $link, $format);
@@ -615,6 +972,14 @@ function adjacent_post_link($format, $link, $in_same_cat = false, $excluded_cate
 	echo apply_filters( "{$adjacent}_post_link", $format, $link );
 }
 
+/**
+ * Retrieve get links for page numbers.
+ *
+ * @since 1.5.0
+ *
+ * @param int $pagenum Optional. Page ID.
+ * @return string
+ */
 function get_pagenum_link($pagenum = 1) {
 	global $wp_rewrite;
 
@@ -669,6 +1034,16 @@ function get_pagenum_link($pagenum = 1) {
 	return $result;
 }
 
+/**
+ * Retrieve next posts pages link.
+ *
+ * Backported from 2.1.3 to 2.0.10.
+ *
+ * @since 2.0.10
+ *
+ * @param int $max_page Optional. Max pages.
+ * @return string
+ */
 function get_next_posts_page_link($max_page = 0) {
 	global $paged;
 
@@ -681,25 +1056,74 @@ function get_next_posts_page_link($max_page = 0) {
 	}
 }
 
-function next_posts($max_page = 0) {
-	echo clean_url(get_next_posts_page_link($max_page));
+/**
+ * Display or return the next posts pages link.
+ *
+ * @since 0.71
+ *
+ * @param int $max_page Optional. Max pages.
+ * @param boolean $echo Optional. Echo or return;
+ */
+function next_posts( $max_page = 0, $echo = true ) {
+	$output = clean_url( get_next_posts_page_link( $max_page ) );
+
+	if ( $echo )
+		echo $output;
+	else
+		return $output;
 }
 
-function next_posts_link($label='Next Page &raquo;', $max_page=0) {
+/**
+ * Return the next posts pages link.
+ *
+ * @since 2.7.0
+ *
+ * @param string $label Content for link text.
+ * @param int $max_page Optional. Max pages.
+ * @return string|null
+ */
+function get_next_posts_link( $label = 'Next Page &raquo;', $max_page = 0 ) {
 	global $paged, $wp_query;
+
 	if ( !$max_page ) {
 		$max_page = $wp_query->max_num_pages;
 	}
+
 	if ( !$paged )
 		$paged = 1;
+
 	$nextpage = intval($paged) + 1;
-	if ( (! is_single()) && (empty($paged) || $nextpage <= $max_page) ) {
-		echo '<a href="';
-		next_posts($max_page);
-		echo '">'. preg_replace('/&([^#])(?![a-z]{1,8};)/', '&#038;$1', $label) .'</a>';
+
+	if ( !is_single() && ( empty($paged) || $nextpage <= $max_page) ) {
+		$attr = apply_filters( 'next_posts_link_attributes', '' );
+		return '<a href="' . next_posts( $max_page, false ) . "\" $attr>". preg_replace('/&([^#])(?![a-z]{1,8};)/', '&#038;$1', $label) .'</a>';
 	}
 }
 
+/**
+ * Display the next posts pages link.
+ *
+ * @since 0.71
+ * @uses get_next_posts_link()
+ *
+ * @param string $label Content for link text.
+ * @param int $max_page Optional. Max pages.
+ */
+function next_posts_link( $label = 'Next Page &raquo;', $max_page = 0 ) {
+	echo get_next_posts_link( $label, $max_page );
+}
+
+/**
+ * Retrieve previous post pages link.
+ *
+ * Will only return string, if not on a single page or post.
+ *
+ * Backported to 2.0.10 from 2.1.3.
+ *
+ * @since 2.0.10
+ *
+ * @return string|null
+ */
 function get_previous_posts_page_link() {
 	global $paged;
 
@@ -711,20 +1135,61 @@ function get_previous_posts_page_link() {
 	}
 }
 
-function previous_posts() {
-	echo clean_url(get_previous_posts_page_link());
+/**
+ * Display or return the previous posts pages link.
+ *
+ * @since 0.71
+ *
+ * @param boolean $echo Optional. Echo or return;
+ */
+function previous_posts( $echo = true ) {
+	$output = clean_url( get_previous_posts_page_link() );
+
+	if ( $echo )
+		echo $output;
+	else
+		return $output;
 }
 
-function previous_posts_link($label='&laquo; Previous Page') {
+/**
+ * Return the previous posts pages link.
+ *
+ * @since 2.7.0
+ *
+ * @param string $label Optional. Previous page link text.
+ * @return string|null
+ */
+function get_previous_posts_link( $label = '&laquo; Previous Page' ) {
 	global $paged;
-	if ( (!is_single())	&& ($paged > 1) ) {
-		echo '<a href="';
-		previous_posts();
-		echo '">'. preg_replace('/&([^#])(?![a-z]{1,8};)/', '&#038;$1', $label) .'</a>';
+
+	if ( !is_single() && $paged > 1 ) {
+		$attr = apply_filters( 'previous_posts_link_attributes', '' );
+		return '<a href="' . previous_posts( false ) . "\" $attr>". preg_replace( '/&([^#])(?![a-z]{1,8};)/', '&#038;$1', $label ) .'</a>';
 	}
 }
 
-function posts_nav_link($sep=' &#8212; ', $prelabel='&laquo; Previous Page', $nxtlabel='Next Page &raquo;') {
+/**
+ * Display the previous posts page link.
+ *
+ * @since 0.71
+ * @uses get_previous_posts_link()
+ *
+ * @param string $label Optional. Previous page link text.
+ */
+function previous_posts_link( $label = '&laquo; Previous Page' ) {
+	echo get_previous_posts_link( $label );
+}
+
+/**
+ * Display post pages link navigation for previous and next pages.
+ *
+ * @since 0.71
+ *
+ * @param string $sep Optional. Separator for posts navigation links.
+ * @param string $prelabel Optional. Label for previous pages.
+ * @param string $nxtlabel Optional Label for next pages.
+ */
+function posts_nav_link( $sep = ' &#8212; ', $prelabel = '&laquo; Previous Page', $nxtlabel = 'Next Page &raquo;' ) {
 	global $wp_query;
 	if ( !is_singular() ) {
 		$max_num_pages = $wp_query->max_num_pages;
@@ -743,6 +1208,172 @@ function posts_nav_link($sep=' &#8212; ', $prelabel='&laquo; Previous Page', $nx
 	}
 }
 
+/**
+ * Retrieve page numbers links.
+ *
+ * @since 2.7.0
+ *
+ * @param int $pagenum Optional. Page number.
+ * @return string
+ */
+function get_comments_pagenum_link( $pagenum = 1, $max_page = 0 ) {
+	global $post, $wp_rewrite;
+
+	$pagenum = (int) $pagenum;
+
+	$result = get_permalink( $post->ID );
+
+	if ( 'newest' == get_option('default_comments_page') ) {
+		if ( $pagenum != $max_page ) {
+			if ( $wp_rewrite->using_permalinks() )
+				$result = user_trailingslashit( trailingslashit($result) . 'comment-page-' . $pagenum, 'commentpaged');
+			else
+				$result = add_query_arg( 'cpage', $pagenum, $result );
+		}
+	} elseif ( $pagenum > 1 ) {
+		if ( $wp_rewrite->using_permalinks() )
+			$result = user_trailingslashit( trailingslashit($result) . 'comment-page-' . $pagenum, 'commentpaged');
+		else
+			$result = add_query_arg( 'cpage', $pagenum, $result );
+	}
+
+	$result .= '#comments';
+
+	$result = apply_filters('get_comments_pagenum_link', $result);
+
+	return $result;
+}
+
+/**
+ * Return the link to next comments pages.
+ *
+ * @since 2.7.1
+ *
+ * @param string $label Optional. Label for link text.
+ * @param int $max_page Optional. Max page.
+ * @return string|null
+ */
+function get_next_comments_link( $label = '', $max_page = 0 ) {
+	global $wp_query;
+
+	if ( !is_singular() )
+		return;
+
+	$page = get_query_var('cpage');
+
+	$nextpage = intval($page) + 1;
+
+	if ( empty($max_page) )
+		$max_page = $wp_query->max_num_comment_pages;
+
+	if ( empty($max_page) )
+		$max_page = get_comment_pages_count();
+
+	if ( $nextpage > $max_page )
+		return;
+
+	if ( empty($label) )
+		$label = __('Newer Comments &raquo;');
+
+	return '<a href="' . clean_url( get_comments_pagenum_link( $nextpage, $max_page ) ) . '" ' . apply_filters( 'next_comments_link_attributes', '' ) . '>'. preg_replace('/&([^#])(?![a-z]{1,8};)/', '&#038;$1', $label) .'</a>';
+}
+
+/**
+ * Display the link to next comments pages.
+ *
+ * @since 2.7.0
+ *
+ * @param string $label Optional. Label for link text.
+ * @param int $max_page Optional. Max page.
+ */
+function next_comments_link( $label = '', $max_page = 0 ) {
+	echo get_next_comments_link( $label, $max_page );
+}
+
+/**
+ * Return the previous comments page link.
+ *
+ * @since 2.7.1
+ *
+ * @param string $label Optional. Label for comments link text.
+ * @return string|null
+ */
+function get_previous_comments_link( $label = '' ) {
+	if ( !is_singular() )
+		return;
+
+	$page = get_query_var('cpage');
+
+	if ( intval($page) <= 1 )
+		return;
+
+	$prevpage = intval($page) - 1;
+
+	if ( empty($label) )
+		$label = __('&laquo; Older Comments');
+
+	return '<a href="' . clean_url( get_comments_pagenum_link( $prevpage ) ) . '" ' . apply_filters( 'previous_comments_link_attributes', '' ) . '>' . preg_replace('/&([^#])(?![a-z]{1,8};)/', '&#038;$1', $label) .'</a>';
+}
+
+/**
+ * Display the previous comments page link.
+ *
+ * @since 2.7.0
+ *
+ * @param string $label Optional. Label for comments link text.
+ */
+function previous_comments_link( $label = '' ) {
+	echo get_previous_comments_link( $label );
+}
+
+/**
+ * Create pagination links for the comments on the current post.
+ *
+ * @see paginate_links()
+ * @since 2.7.0
+ *
+ * @param string|array $args Optional args. See paginate_links.
+ * @return string Markup for pagination links.
+*/
+function paginate_comments_links($args = array()) {
+	global $wp_query, $wp_rewrite;
+
+	if ( !is_singular() )
+		return;
+
+	$page = get_query_var('cpage');
+	if ( !$page )
+		$page = 1;
+	$max_page = get_comment_pages_count();
+	$defaults = array(
+		'base' => add_query_arg( 'cpage', '%#%' ),
+		'format' => '',
+		'total' => $max_page,
+		'current' => $page,
+		'echo' => true,
+		'add_fragment' => '#comments'
+	);
+	if ( $wp_rewrite->using_permalinks() )
+		$defaults['base'] = user_trailingslashit(trailingslashit(get_permalink()) . 'comment-page-%#%', 'commentpaged');
+
+	$args = wp_parse_args( $args, $defaults );
+	$page_links = paginate_links( $args );
+
+	if ( $args['echo'] )
+		echo $page_links;
+	else
+		return $page_links;
+}
+
+/**
+ * Retrieve shortcut link.
+ *
+ * Use this in 'a' element 'href' attribute.
+ *
+ * @since 2.6.0
+ *
+ * @return string
+ */
 function get_shortcut_link() {
 	$link = "javascript:
 			var d=document,
@@ -756,7 +1387,7 @@ function get_shortcut_link() {
 			e=encodeURIComponent,
 			g=f+'?u='+e(l.href)+'&t='+e(d.title)+'&s='+e(s)+'&v=2';
 			function a(){
-				if(!w.open(g,'t','toolbar=0,resizable=0,scrollbars=1,status=1,width=700,height=500')){
+				if(!w.open(g,'t','toolbar=0,resizable=0,scrollbars=1,status=1,width=720,height=570')){
 					l.href=g;
 				}
 			}";
@@ -772,21 +1403,23 @@ function get_shortcut_link() {
 	return apply_filters('shortcut_link', $link);
 }
 
-/** Return the site url
+/**
+ * Retrieve the site url.
  *
+ * Returns the 'site_url' option with the appropriate protocol,  'https' if
+ * is_ssl() and 'http' otherwise. If $scheme is 'http' or 'https', is_ssl() is
+ * overridden.
  *
  * @package WordPress
- * @since 2.6
+ * @since 2.6.0
  *
- * Returns the 'site_url' option with the appropriate protocol,  'https' if is_ssl() and 'http' otherwise. 
- * If $scheme is 'http' or 'https', is_ssl() is overridden.
- *
- * @param string $path Optional path relative to the site url
- * @param string $scheme Optional scheme to give the site url context. Currently 'http','https', 'login', 'login_post', or 'admin'
- * @return string Site url link with optional path appended
+ * @param string $path Optional. Path relative to the site url.
+ * @param string $scheme Optional. Scheme to give the site url context. Currently 'http','https', 'login', 'login_post', or 'admin'.
+ * @return string Site url link with optional path appended.
 */
 function site_url($path = '', $scheme = null) {
 	// should the list of allowed schemes be maintained elsewhere?
+	$orig_scheme = $scheme;
 	if ( !in_array($scheme, array('http', 'https')) ) {
 		if ( ('login_post' == $scheme) && ( force_ssl_login() || force_ssl_admin() ) )
 			$scheme = 'https';
@@ -803,16 +1436,14 @@ function site_url($path = '', $scheme = null) {
 	if ( !empty($path) && is_string($path) && strpos($path, '..') === false )
 		$url .= '/' . ltrim($path, '/');
 
-	return $url;
+	return apply_filters('site_url', $url, $path, $orig_scheme);
 }
 
-/** Return the admin url
- *
+/**
+ * Retrieve the url to the admin area.
  *
  * @package WordPress
- * @since 2.6
- *
- * Returns the url to the admin area
+ * @since 2.6.0
  *
  * @param string $path Optional path relative to the admin url
  * @return string Admin url link with optional path appended
@@ -826,16 +1457,14 @@ function admin_url($path = '') {
 	return $url;
 }
 
-/** Return the includes url
- *
+/**
+ * Retrieve the url to the includes directory.
  *
  * @package WordPress
- * @since 2.6
+ * @since 2.6.0
  *
- * Returns the url to the includes directory
- *
- * @param string $path Optional path relative to the includes url
- * @return string Includes url link with optional path appended
+ * @param string $path Optional. Path relative to the includes url.
+ * @return string Includes url link with optional path appended.
 */
 function includes_url($path = '') {
 	$url = site_url() . '/' . WPINC . '/';
@@ -846,16 +1475,14 @@ function includes_url($path = '') {
 	return $url;
 }
 
-/** Return the content url
- *
+/**
+ * Retrieve the url to the content directory.
  *
  * @package WordPress
- * @since 2.6
+ * @since 2.6.0
  *
- * Returns the url to the content directory
- *
- * @param string $path Optional path relative to the content url
- * @return string Content url link with optional path appended
+ * @param string $path Optional. Path relative to the content url.
+ * @return string Content url link with optional path appended.
 */
 function content_url($path = '') {
 	$scheme = ( is_ssl() ? 'https' : 'http' );
@@ -871,16 +1498,14 @@ function content_url($path = '') {
 	return $url;
 }
 
-/** Return the plugins url
- *
+/**
+ * Retrieve the url to the plugins directory.
  *
  * @package WordPress
- * @since 2.6
+ * @since 2.6.0
  *
- * Returns the url to the plugins directory
- *
- * @param string $path Optional path relative to the plugins url
- * @return string Plugins url link with optional path appended
+ * @param string $path Optional. Path relative to the plugins url.
+ * @return string Plugins url link with optional path appended.
 */
 function plugins_url($path = '') {
 	$scheme = ( is_ssl() ? 'https' : 'http' );
